==> haskell-hs-bibutils-6.2.0.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hs-bibutils
version: 6.2.0.1
id: hs-bibutils-6.2.0.1-ewhJkVIVTX3sjVOz1mire
key: hs-bibutils-6.2.0.1-ewhJkVIVTX3sjVOz1mire
license: GPL
maintainer: Václav Haisman <vhaisman@gmail.com>
homepage: https://github.com/wilx/hs-bibutils
synopsis: Haskell bindings to bibutils, the bibliography
          conversion utilities.
description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.
    .
    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.
    .
    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.
    .
    The package release number refers to the release number of
    the included bibutils library.
category: Text
author: Andrea Rossato
exposed: True
indefinite: False
exposed-modules:
    Text.Bibutils
abi: 791fa2701c10d2ee03a556b8589cbd19
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hs-bibutils-6.2.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hs-bibutils-6.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/hs-bibutils-6.2.0.1
hs-libraries: HShs-bibutils-6.2.0.1-ewhJkVIVTX3sjVOz1mire
includes:
    bibutils.h
depends:
    base-4.10.0.0 syb-0.7-2rRPTNxBP6YFePrCXw4i2o
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=119e2c6ac6f570dd5e30835fe9c8c288
haddock-interfaces: /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html: /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hs-bibutils-6.2.0.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hs-bibutils
version: 6.2.0.1
id: hs-bibutils-6.2.0.1-84TTSwXWiCRJ5Tq4TVL8yp
key: hs-bibutils-6.2.0.1-84TTSwXWiCRJ5Tq4TVL8yp
license: GPL
maintainer: Václav Haisman <vhaisman@gmail.com>
homepage: https://github.com/wilx/hs-bibutils
synopsis: Haskell bindings to bibutils, the bibliography
          conversion utilities.
description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.
    .
    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.
    .
    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.
    .
    The package release number refers to the release number of
    the included bibutils library.
category: Text
author: Andrea Rossato
exposed: True
indefinite: False
exposed-modules:
    Text.Bibutils
abi: 1273121c398f59529051b9fdb28359ce
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hs-bibutils-6.2.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/hs-bibutils-6.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hs-bibutils-6.2.0.1
hs-libraries: HShs-bibutils-6.2.0.1-84TTSwXWiCRJ5Tq4TVL8yp
includes:
    bibutils.h
depends:
    base-4.10.1.0 syb-0.7-3Lq8MQxmYP07qktjI1jxu0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
haddock-interfaces: /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html: /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
